# `BioClients.chemidplus`

##  ChemIdPlus

NIH NLM ChemIdPlus REST API client

  * <https://chem.nlm.nih.gov/chemidsearch/api>
  * <https://chem.nlm.nih.gov/api/swagger-ui.html>
  * <https://chem.nlm.nih.gov/api/v2/api-docs>
